==> wildfly-dist-21.0.0.Final-src.tar.gz: wildfly-21.0.0.Final-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/jaxrs/multipart/MultipartResource.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.jaxrs.multipart;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

import org.jboss.resteasy.plugins.providers.multipart.MultipartFormDataOutput;

/**
 * @author Stuart Douglas
 */
@Path("/form")
public class MultipartResource {

    @GET
    @Produces("multipart/related")
    public MultipartFormDataOutput get() {
        MultipartFormDataOutput output = new MultipartFormDataOutput();
        output.addPart("Hello", MediaType.TEXT_PLAIN_TYPE);
        output.addPart("World", MediaType.TEXT_PLAIN_TYPE);
        return output;
    }
}

==> wildfly-dist-29.0.0.Final-src.tar.gz: wildfly-29.0.0.Final-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/jaxrs/multipart/MultipartResource.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.jaxrs.multipart;

import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;

import org.jboss.resteasy.plugins.providers.multipart.MultipartFormDataOutput;

/**
 * @author Stuart Douglas
 */
@Path("/form")
public class MultipartResource {

    @GET
    @Produces("multipart/related")
    public MultipartFormDataOutput get() {
        MultipartFormDataOutput output = new MultipartFormDataOutput();
        output.addPart("Hello", MediaType.TEXT_PLAIN_TYPE);
        output.addPart("World", MediaType.TEXT_PLAIN_TYPE);
        return output;
    }
}
